==> librenms-1.67v0.tgz: librenms/doc/Support/Features.md <==
source: Support/Features.md
path: blob/master/doc/

# Features

Here's a brief list of supported features, some might be missing.
If you think something is missing, feel free to ask us.

* Auto discovery
* Alerting
* Multiple environnement sensors support
* Multiple protocols data collection (STP, OSPF, BGP etc)
* VLAN, ARP and FDB table collection
* Customizable Dashboards
* Device Backup integration (Oxidized, RANCID)
* Distributed Polling
* Multiple Authentication Methods (MySQL, LDAP, Active Directory, HTTP)
* NetFlow, sFlow, IPFIX (NfSen)
* Service monitoring (Nagios Plugins)
* Syslog (Integrated, Graylog)
* Traffic Billing (Quota, 95th Percentile)
* Two Factor Authentication
* API
* Auto Updating

# Vendors

Here's a brief list of supported vendors, some might be missing.
If you are unsure of whether your device is supported or not, feel free to ask us.

* 3Com
* ADTRAN
* Acceidan
* Aerohive
* AKCP
* Alcatel-Lucent
* Allied Telesis
* APC
* Apple
* Areca
* Arista
* Aruba
* Audiocodes
* Avaya
* Avocent
* AVTECH
* Axis
* Barracuda
* BCM963
* BDCom
* Bintec
* Bluecat
* BNT
* Brocade
* Brother
* Buffalo
* Calix
* Cambium
* Canon
* Canopy
* Check Point
* Cisco
* Cisco Small Business
* Citrix
* Cometsystem
* Comware
* D-Link
* Datacom
* Deliberant
* Dell
* Delta Power Solutions
* DEVELOP
* DKT Comega
* Eaton
* EDS
* EMC
* Engenius
* Enterasys
* Epson
* Extreme Networks
* F5
* Fastback Networks
* Fiberstore
* FiberHome
* Force10
* Fortinet
* FreeBSD
* Gamatronic
* Hikvision
* HP
* Huawei
* HW group
* IBM
* Infoblox
* iPoMan
* ITWatchDogs
* Juniper
* Konica Minolta
* Kyocera
* Lantronix
* Lenovo
* Lexmark
* Liebert
* LigoWave
* Linux
* Maipu
* Mellanox
* Meraki
* MGE
* Microsemi
* Mikrotik
* MRVLD
* Multimatic
* NetApp
* NetBSD
* NETGEAR
* NetMan
* Netonix
* Netopia
* NetVision
* NetWare
* Nokia
* NRG
* OKI
* OpenBSD
* Oracle
* PacketShaper
* Palo Alto Networks
* Papouch
* PBN
* Perle
* Powercode
* Powerwalker
* Prestige
* Proxim
* Proxmox
* Quanta
* Radlan
* Raritan
* Redback
* Ricoh
* Riverbed
* Ruckus
* SAF Tehnika
* Samsung
* Siklu
* Sentry3
* Solaris
* SonicWALL
* SpeedTouch
* Supermicro
* Symbol
* Telco Systems
* TPLink
* Tranzeo
* Tripp Lite
* Ubiquiti
* Viprinet
* VMware
* VRP
* Vyatta
* VyOS
* Watchguard
* WebPower
* Windows
* Xerox
* Xirrus
* ZTE
* ZyXEL

==> librenms-21.1.0v0.tgz: librenms/doc/Support/Features.md <==
source: Support/Features.md
path: blob/master/doc/

# Features

Here's a brief list of supported features, some might be missing.
If you think something is missing, feel free to ask us.

* Auto discovery
* Alerting
* Multiple environment sensors support
* Multiple protocols data collection (STP, OSPF, BGP etc)
* VLAN, ARP and FDB table collection
* Customizable Dashboards
* Device Backup integration (Oxidized, RANCID)
* Distributed Polling
* Multiple Authentication Methods (MySQL, LDAP, Active Directory, HTTP)
* NetFlow, sFlow, IPFIX (NfSen)
* Service monitoring (Nagios Plugins)
* Syslog (Integrated, Graylog)
* Traffic Billing (Quota, 95th Percentile)
* Two Factor Authentication
* API
* Auto Updating

# Vendors

Here's a brief list of supported vendors, some might be missing.
If you are unsure of whether your device is supported or not, feel free to ask us.

* 3Com
* ADTRAN
* Acceidan
* Aerohive
* AKCP
* Alcatel-Lucent
* Allied Telesis
* APC
* Apple
* Areca
* Arista
* Aruba
* Audiocodes
* Avaya
* Avocent
* AVTECH
* Axis
* Barracuda
* BCM963
* BDCom
* Bintec
* Bluecat
* BNT
* Brocade
* Brother
* Buffalo
* Calix
* Cambium
* Canon
* Canopy
* Check Point
* Cisco
* Cisco Small Business
* Citrix
* Cometsystem
* Comware
* D-Link
* Datacom
* Deliberant
* Dell
* Delta Power Solutions
* DEVELOP
* DKT Comega
* Eaton
* EDS
* EMC
* Engenius
* Enterasys
* Epson
* Extreme Networks
* F5
* Fastback Networks
* Fiberstore
* FiberHome
* Force10
* Fortinet
* FreeBSD
* Gamatronic
* Hikvision
* HP
* Huawei
* HW group
* IBM
* Infoblox
* iPoMan
* ITWatchDogs
* Juniper
* Konica Minolta
* Kyocera
* Lantronix
* Lenovo
* Lexmark
* Liebert
* LigoWave
* Linux
* Maipu
* Mellanox
* Meraki
* MGE
* Microsemi
* Mikrotik
* MRVLD
* Multimatic
* NetApp
* NetBSD
* NETGEAR
* NetMan
* Netonix
* Netopia
* NetVision
* NetWare
* Nokia
* NRG
* OKI
* OpenBSD
* Oracle
* PacketShaper
* Palo Alto Networks
* Papouch
* PBN
* Perle
* Powercode
* Powerwalker
* Prestige
* Proxim
* Proxmox
* Quanta
* Radlan
* Raritan
* Redback
* Ricoh
* Riverbed
* Ruckus
* SAF Tehnika
* Samsung
* Siklu
* Sentry3
* Solaris
* SonicWALL
* SpeedTouch
* Supermicro
* Symbol
* Telco Systems
* TPLink
* Tranzeo
* Tripp Lite
* Ubiquiti
* Viprinet
* VMware
* VRP
* Vyatta
* VyOS
* Watchguard
* WebPower
* Windows
* Xerox
* Xirrus
* ZTE
* ZyXEL
